@@ -20,7 +20,7 @@ use Types::Standard qw/ Bool CodeRef HashRef Maybe Tuple /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.3.0';
+our $VERSION = 'v0.3.1';
 
 
 
@@ -60,7 +60,7 @@ has prefer_min => (
 has css_files => (
     is  => 'lazy',
     isa => STRICT
-             ? HashRef [ Tuple [ Maybe[Path], NonEmptySimpleStr, PositiveOrZeroInt ] ]
+             ? HashRef [ Tuple [ Maybe[Path], Maybe[NonEmptySimpleStr], PositiveOrZeroInt ] ]
              : HashRef,
     builder => 1,
     coerce  => 1,
@@ -78,8 +78,11 @@ sub _build_css_files {
 
     my %files;
     for my $name (keys %{ $self->aliases }) {
-        my $base  = $self->aliases->{$name} or next;
-        if ($base =~ m{^(\w+:)?//}) {
+        my $base  = $self->aliases->{$name};
+        if (!$base) {
+            $files{$name} = [ undef, undef, 0 ];
+        }
+        elsif ($base =~ m{^(\w+:)?//}) {
             $files{$name} = [ undef, $base, 0 ];
         }
         else {
@@ -216,7 +219,12 @@ sub href {
 
 sub link_html {
     my ( $self, $name, $file ) = @_;
-    return $self->link_template->( $self->href( $name, $file ) );
+    if (my $href = $self->href( $name, $file )) {
+        return $self->link_template->($href);
+    }
+    else {
+        return "";
+    }
 }
 
 
@@ -319,7 +327,7 @@ HTML::DeferableCSS - Simplify management of stylesheets in your HTML
 
 =head1 VERSION
 
-version v0.3.0
+version v0.3.1
 
 =head1 SYNOPSIS
 
@@ -412,7 +420,7 @@ the alias:
   my $css = HTML::DeferableCSS->new(
     aliases => {
         reset => 1,
-        gone  => 0,       # using "gone" will throw an error
+        gone  => 0,       # "gone" will be silently ignored
         one   => "1.css", #
     }
     ...
@@ -426,6 +434,13 @@ can be used:
     ...
   );
 
+If an alias is disabled, then it will simply be ignored, e.g.
+
+  $css->deferred_link_html('gone')
+
+Returns an empty string.  This allows you to disable a stylesheet in
+your configuration without having to remove all references to it.
+
 Absolute paths cannot be used.
 
 You may specify URLs instead of files, but this is not recommended,
